# amhelpers

A collection of handy utilities.

## Installation

```bash
$ pip install amhelpers
```

## License

`amhelpers` was created by Anton Matsson. It is licensed under the terms of the MIT license.

## Credits

`amhelpers` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
